@@ -21,8 +21,12 @@
 #' @import Rcpp
 .onLoad <- function(libname, pkgname)
 {
+    Rcpp::loadModule("bimap_module", TRUE)
     Rcpp::loadModule("hashmap_module", TRUE)
+
+    Rcpp::loadModule("binomial_heap_module", TRUE)
     Rcpp::loadModule("fibonacci_heap_module", TRUE)
+
     Rcpp::loadModule("queue_module", TRUE)
     Rcpp::loadModule("stack_module", TRUE)
 }
