@@ -1,8 +1,9 @@
-## ---- message=FALSE, warning=FALSE---------------------------------------
+## ---- eval=TRUE, include=FALSE-------------------------------------------
   library(datastructures)
 
 ## ------------------------------------------------------------------------
-    fheap <- new("fibonacci_heap", "numeric", "character")
+  fheap <- fibonacci_heap("numeric", "character")
+  bheap <- binomial_heap("numeric", "character")
 
 ## ------------------------------------------------------------------------
   keys   <- sample(seq(0, 1, by=.2))
@@ -23,28 +24,39 @@
   peek(fheap)
 
 ## ------------------------------------------------------------------------
-  hash <- new("hashmap", "character", "integer")
+  hash  <- hashmap("character", "integer")
+  bimap <- bimap("character", "integer")
 
 ## ------------------------------------------------------------------------
-  keys    <- paste0("V", 1:5)
-  values  <- 1:5
-  hash    <- insert(hash, keys[1:4], values[1:4])
-  hash[keys[5]] <- values[5]
-  size(hash)
+  keys   <- paste0("V", 1:5)
+  values <- 1:5
+  hash   <- insert(hash, keys[1:4], values[1:4])
+  bimap  <- insert(bimap, keys[1:4], values[1:4])
+  hash[keys[5]]  <- values[5]
+  bimap[keys[5]] <- values[5]
 
 ## ------------------------------------------------------------------------
   get(hash, keys[1])
   hash[keys[1]]
+  
+  get(bimap, keys[1], "values")
+  get(bimap, values[2], "keys")
+  get(bimap, keys[1])
 
 ## ------------------------------------------------------------------------
-  qu <- new("queue", "numeric")
-  st <- new("stack", "numeric")
+  keys(bimap)
+  values(hash)
+  head(bimap)
+
+## ------------------------------------------------------------------------
+  qu <- queue("numeric")
+  st <- stack("numeric")
 
 ## ------------------------------------------------------------------------
   keys <- seq(0, 1, by=.2)
   print(keys)
-  insert(qu, keys)
-  insert(st, keys)
+  qu <- insert(qu, keys)
+  st <- insert(st, keys)
 
 ## ------------------------------------------------------------------------
   peek(qu)
